@@ -4,6 +4,7 @@
 #' @param sampleList List of RasterStack objects.
 #' @param landList Landmark list as returned by \code{\link[patternize]{makeList}}.
 #' @param k Integere for defining number of k-means clusters (default = 3).
+#' @param fixedStartCenter Specify a dataframe with start centers for k-means clustering.
 #' @param resampleFactor Integer for downsampling used by \code{\link{redRes}}.
 #' @param crop Whether to use the landmarks range to crop the image. This can significantly speed
 #'    up the analysis (default = FALSE).
@@ -17,9 +18,9 @@
 #'    to. Can be 'meanshape' for transforming to mean shape of Procrustes analysis.
 #' @param transformType Transformation type as used by \code{\link[Morpho]{computeTransform}}
 #'    (default ='tps').
-#' @param removebgK Integer indicating the range RGB treshold to remove from image (e.g. 100
-#'    removes pixels with average RGB > 100; default = NULL) for k-means analysis. This works only
-#'    to remove a white background.
+#' @param removebg Integer or RGB vector indicating the range of RGB threshold to remove from
+#'    image (e.g. 100 removes pixels with average RGB > 100; default = NULL).
+#' @param removebgColOffset Color offset for color background extraction (default = 0.10).
 #' @param adjustCoords Adjust landmark coordinates in case they are reversed compared to pixel
 #'    coordinates (default = FALSE).
 #' @param plot Whether to plot transformed color patterns while processing (default = FALSE).
@@ -40,7 +41,7 @@
 #' # Note that this example only aligns two images with the target,
 #' # remove [1:2] to run a full examples.
 #' rasterList_lanK <- patLanK(imageList[1:2], landmarkList[1:2], k = 4, crop = TRUE,
-#' res = 100, removebgK = 100, adjustCoords = TRUE, plot = TRUE)
+#' res = 100, removebg = 100, adjustCoords = TRUE, plot = TRUE)
 #' }
 #'
 #' @export
@@ -51,13 +52,15 @@
 patLanK <- function(sampleList,
                     landList,
                     k = 3,
+                    fixedStartCenter = NULL,
                     resampleFactor = NULL,
                     crop = FALSE,
                     cropOffset = c(0,0,0,0),
                     res = 300,
                     transformRef = 'meanshape',
                     transformType='tps',
-                    removebgK = NULL,
+                    removebg = NULL,
+                    removebgColOffset = 0.1,
                     adjustCoords = FALSE,
                     plot = FALSE,
                     focal =  FALSE,
@@ -133,35 +136,59 @@ patLanK <- function(sampleList,
       image <- raster::stack(rrr1, rrr2, rrr3)
     }
 
-    if(is.vector(removebgK)){
+    if(is.vector(removebg)){
 
-      toMask <- apply(raster::as.array(image), 1:2, function(x) all(x > removebgK))
+      if(length(removebg) > 1){
+        toMask <- apply(raster::as.array(image), 1:2, function(x) all(abs(x-removebg) < removebgColOffset*255))
+      }
+      else{
+        toMask <- apply(raster::as.array(image), 1:2, function(x) all(x > removebg))
+      }
 
       toMaskR <- raster::raster(as.matrix(toMask))
       raster::extent(toMaskR) <- raster::extent(image)
       toMaskR[toMaskR == 0] <- NA
 
       image<-raster::mask(image, toMaskR, inverse = T)
-      image[is.na(image)] <- 0
+      # image[is.na(image)] <- 0
     }
 
     # k-means clustering of image
 
-    if(n==1){
+    if(n==1 & is.null(fixedStartCenter)){
       startCenter = NULL
     }
 
-    else{
-      startCenter <- K$centers
+    if(!is.null(fixedStartCenter)){
+      startCenter <- fixedStartCenter
+      print(paste('Fixed centers:', startCenter, sep = ' '))
     }
 
-    image[is.na(image)] <- 255
-    imageKmeans <- kImage(raster::as.array(image), k, startCenter)
+    # else{
+    #   startCenter <- K$centers
+    # }
+
+    # image[is.na(image)] <- 255
+
+
+    imageKmeans <- tryCatch(kImage(raster::as.array(image), k, startCenter),
+                            error = function(err) {
+                              print(paste('sample', names(sampleList)[n], 'k-clustering failed and skipped', sep = ' '))
+                              return(NULL)
+                            })
+    if(is.null(imageKmeans)){next}
 
     image.segmented <- imageKmeans[[1]]
     K <- imageKmeans[[2]]
 
+    if(n==1 & is.null(fixedStartCenter)){
+      startCenter <- K$centers
+      print('start centers of first image:')
+      print(startCenter)
+    }
+
     if(plot){
+      image.segmented[is.na(image.segmented)] <- 0
       x <- image.segmented/255
       cols <- rgb(x[,,1], x[,,2], x[,,3], maxColorValue=1)
       uniqueCols <- unique(cols)
