@@ -4,6 +4,9 @@
 #' @param sampleList List of RasterStack objects.
 #' @param landList Landmark list as returned by \code{\link[patternize]{makeList}}.
 #' @param RGB RGB values for color pattern extraction specified as vector.
+#' @param sampleRGB Whether to set RGB for each image manually.
+#' @param sampleRGBtype Whether to pick a point or area (defined by left bottom and top right)
+#'    for sampleRGB.
 #' @param resampleFactor Integer for downsampling used by \code{\link{redRes}}.
 #' @param colOffset Color offset for color pattern extraction (default = 0.10).
 #' @param crop Whether to use the landmarks range to crop the image. This can speed up the
@@ -26,6 +29,10 @@
 #' @param focal Whether to perform Gaussian blurring (default = FALSE).
 #' @param sigma Size of sigma for Gaussian blurring (default = 3).
 #' @param iterations Number of iterations for recalculating average color.
+#' @param imageIDs A list of IDs to match landmarks to images if landmarkList and imageList don't
+#'    have the same length.
+#' @param patternsToFile Name of directory to which the color pattern of each individual will be
+#'    outputted (default = NULL).
 #'
 #' @return  List of raster objects.
 #'
@@ -51,10 +58,13 @@
 #' @importFrom utils capture.output
 #' @importFrom stats na.omit
 #' @importFrom Morpho procSym computeTransform applyTransform
+#' @importFrom grDevices dev.off png
 
 patLanRGB <- function(sampleList,
                       landList,
-                      RGB,
+                      RGB = NULL,
+                      sampleRGB = FALSE,
+                      sampleRGBtype = 'point',
                       resampleFactor = NULL,
                       colOffset = 0.10,
                       crop = FALSE,
@@ -66,21 +76,25 @@ patLanRGB <- function(sampleList,
                       plot = NULL,
                       focal =  FALSE,
                       sigma = 3,
-                      iterations = 0){
+                      iterations = 0,
+                      imageIDs = NULL,
+                      patternsToFile = NULL){
 
   rasterList <- list()
 
-  if(length(sampleList) != length(landList)){
-    stop("sampleList is not of the same length as lanArray")
-  }
+  if(is.null(imageIDs)){
+    if(length(sampleList) != length(landList)){
+      stop("sampleList is not of the same length as lanArray")
+    }
 
-  for(n in 1:length(sampleList)){
-    if(names(sampleList)[n] != names(landList)[n]){
-      stop("samples are not in the same order in sampleList and lanArray")
+    for(n in 1:length(sampleList)){
+      if(names(sampleList)[n] != names(landList)[n]){
+        stop("samples are not in the same order in sampleList and lanArray")
+      }
     }
   }
 
-  lanArray <- lanArray(landList, adjustCoords, sampleList)
+  lanArray <- lanArray(landList, adjustCoords, sampleList, imageIDs)
 
   if(is.matrix(transformRef)){
 
@@ -105,9 +119,14 @@ patLanRGB <- function(sampleList,
   }
 
 
-  for(n in 1:length(sampleList)){
+  for(n in 1:length(landList)){
 
-    image <- sampleList[[n]]
+    if(is.null(imageIDs)){
+      image <- sampleList[[n]]
+    }
+    if(!is.null(imageIDs)){
+      image <- sampleList[[imageIDs[n]]]
+    }
     extRasterOr <- raster::extent(image)
 
     if(!is.null(resampleFactor)){
@@ -126,7 +145,7 @@ patLanRGB <- function(sampleList,
       imageC <- raster::crop(image, extRaster)
 
       y <- raster::raster(ncol = dim(image)[2], nrow = dim(image)[1])
-      extent(y) <- extRasterOr
+      raster::extent(y) <- extRasterOr
       image <- resample(imageC, y)
     }
 
@@ -140,19 +159,29 @@ patLanRGB <- function(sampleList,
       image <- raster::stack(rrr1, rrr2, rrr3)
     }
 
+    if(sampleRGB == TRUE){
+      if(crop){imageS <- raster::crop(image, extRaster)}
+      RGB <- sampleRGB(imageS, type = sampleRGBtype)
+    }
+    else{
+      if(is.null(RGB)){
+        stop("You forgot to specify the RGB value")
+        }
+    }
+
     map <- apply(raster::as.array(image), 1:2, function(x) all(abs(x-RGB) < colOffset*255))
 
-    if(all(map == FALSE)){
-      warning("The RGB range does not seem to overlap with any of the RGB values in the image")
+    if(all(map == FALSE, na.rm =T)){
+      print(paste("The RGB range does not seem to overlap with any of the RGB values in the image", names(landList)[n], sep = ' '))
     }
 
-    if(iterations > 0){
-      if(all(map == FALSE)){
-        warning("Iterations can't be performed")
-      }
-    }
+    # if(iterations > 0){
+    #   if(all(map == FALSE, na.rm =T)){
+    #     warning("Iterations can't be performed")
+    #   }
+    # }
 
-    if(!all(map == FALSE)){
+    if(!all(map == FALSE, na.rm =T)){
 
       x <- 1
       while(x <= iterations){
@@ -206,28 +235,17 @@ patLanRGB <- function(sampleList,
 
     else{
 
-      if(transformRef == 'meanshape' || is.matrix(transformRef)){
-
-        patternRaster <- raster::extent(min(refShape[,1])-3*max(refShape[,1])*cropOffset[3]/100,
-                                        max(refShape[,1])+3*max(refShape[,1])*cropOffset[4]/100,
-                                        min(refShape[,2])-3*max(refShape[,2])*cropOffset[1]/100,
-                                        max(refShape[,2])+3*max(refShape[,2])*cropOffset[2]/100)
-      }
-
-      else{
-
         patternRaster <- raster::raster(extent(min(refShape[,1])-max(refShape[,1])*cropOffset[1]/100,
                                                max(refShape[,1])+max(refShape[,1])*cropOffset[2]/100,
                                                min(refShape[,2])-max(refShape[,2])*cropOffset[3]/100,
                                                max(refShape[,2])+max(refShape[,2])*cropOffset[4]/100),
                                         ncol = res, nrow = res, vals = rep(NA, res*res))
-      }
     }
 
     if(plot == 'stack'){
 
       par(mfrow=c(1,1))
-      if(n == 1){
+      if(n == 1 | sampleRGB){
         plot(1, type="n", xlab='', ylab='', xaxt='n', yaxt='n', axes= FALSE, bty='n')
       }
 
@@ -242,7 +260,8 @@ patLanRGB <- function(sampleList,
         patternRasterP <- patternRaster
       }
 
-      plot(patternRasterP, col=rgb(1,0,0,alpha=1/length(sampleList)), legend = FALSE, xaxt='n', yaxt='n', axes= FALSE, bty='n')
+      plot(patternRasterP, col=rgb(1,0,0,alpha=1/length(landList)), legend = FALSE, xaxt='n', yaxt='n', axes= FALSE, bty='n')
+
     }
 
     if(plot == 'compare'){
@@ -276,5 +295,31 @@ patLanRGB <- function(sampleList,
     print(paste('sample', names(landList)[n], 'done and added to rasterList', sep=' '))
   }
 
+  if(plot == 'compare' | sampleRGB){
+    for(e in 1:length(rasterList)){
+      if(e == 1){
+        plot(1, type="n", xlab='', ylab='', xaxt='n', yaxt='n', axes= FALSE, bty='n')
+      }
+      par(new = TRUE)
+      raster::plot(rasterList[[e]], col=rgb(1,0,0,alpha=1/length(sampleList)), legend = FALSE, xaxt='n', yaxt='n', axes= FALSE, bty='n')
+
+    }
+  }
+
+  if(!is.null(patternsToFile)){
+
+    dir.create(file.path(patternsToFile), showWarnings = FALSE)
+
+    png(paste(patternsToFile, '/', names(sampleList)[n], '.png', sep=''))
+
+    plot(1, type="n", axes = FALSE, xlab='', ylab='', main = names(sampleList)[n])
+    par(new = TRUE)
+    raster::plot(patternRaster, col=rgb(1,0,0,alpha=1), legend = FALSE)
+
+    dev.off()
+  }
+
+
+
   return(rasterList)
 }
